==> fengoffice_1.7.5.zip: fengoffice/language/es_la/actions.php <==
<?php return array(
	'register' => 'Registrar',
	'login' => 'Login',
	'logout' => 'Logout',
	'hide welcome info' => '» Ocultar información de forma permanente',
	'add company' => 'Agregar empresa',
	'edit company' => 'Editar datos de la empresa',
	'delete company' => 'Eliminar empresa',
	'edit company logo' => 'Guardar logo',
	'delete company logo' => 'Eliminar logo',
	'add client' => 'Agregar cliente',
	'edit client' => 'Editar cliente',
	'delete client' => 'Eliminar cliente',
	
	// Persons
	'add user' => 'Agregar Persona',
	'add user role' => 'Rol',
  	'add user action' => 'Agregar persona para usar tu Feng Office',
  	'add user button' => 'Agregar Persona',
  	'add user hide settings' => 'Ocultar todas las Configuaraciones para este Usuario',
  	'add user show settings' => 'Ver todas las Configuaraciones para este Usuario',
  	'add user show settings text' => 'Como esta persona va a usar el Feng Office, es posible que desee establecer los detalles específicos, como los permisos de acceso<br /> (limitado por defecto), zona horaria, la contraseña, la categoría de facturación, etc.',
  	'add user essential' => 'Información Escencial',
  	'add user essential text' => 'Esta es la única información obligatoria en este formulario. Después de hacer clic en "Añadir persona"<br /> la dirección de correo electrónico recibirán una invitación para unirse a su Feng Office.',
	'add user what does' => 'Qué hace esta Persona',
	'add user what does text' => 'Usted dirá mucho acerca de una persona mediante el establecimiento de la función y en qué compañía.<br />Al seleccionar una función de usuario se define como la persona que, básicamente, usar el Feng Office.',
	'add user others' => 'Acceso y Otras Configuraciones',
	'add user others text' => 'Establecer qué proyectos se esta persona pueda tener acceso. Establecer contraseñas, zona horaria, idioma y otras opciones de configuración del sistema.',
	'edit user' => 'Editar usuario',
	'delete user' => 'Eliminar usuario',
	'create user from contact' => 'Crear usuario a partir de un contacto existente',
	'add group' => 'Agregar grupo',
	'edit group' => 'Editar grupo',
	'delete group' => 'Eliminat grupo',
	'add project' => 'Agregar espacio',
	'edit project' => 'Editar espacio',
	'delete project' => 'Eliminar espacio',
	'mark project as finished' => 'Marcar espacio como cerrado',
	'mark project as active' => 'Marcar espacio como activo',
	'add workspace' => 'Agregar nuevo espacio',
	'edit workspace' => 'Editar espacio',
	'delete workspace' => 'Eliminar espacio',
	'mark workspace as finished' => 'Marcar espacio como finalizado',
	'mark workspace as active' => 'Marcar espacio como activo',
	'add message' => 'Agregar nota',
	'add new message' => 'Agregar nuevo nota',
	'edit message' => 'Editar nota',
	'delete message' => 'Eliminar nota',
	'view message' => 'Mostrar nota',
	'update message options' => 'Guardar nuevas opciones',
	'subscribe to object' => 'Suscribir',
	'unsubscribe from object' => 'Borrar suscripcion',
	'add comment' => 'Agregar comentario',
	'edit comment' => 'Editar comentario',
	'add task list' => 'Agregar tarea',
	'edit task list' => 'Editar tarea',
	'delete task list' => 'Eliminar tarea',
	'reorder tasks' => 'Reordenar tareas',
	'apply milestone to subtasks' => 'Aplicar Hito a Subtareas',
	'apply workspace to subtasks' => 'Aplicar Espacio de Trabajo a Subtareas',
	'reorder sub tasks' => 'Reordenar sub tareas',
	'copy task' => 'Crear copia de esta tarea',
	'copy milestone' => 'Crear copia de este hito',
	'add task' => 'Agregar tarea',
	'add sub task' => 'Agregar subtarea',
	'edit task' => 'Editar tarea',
	'delete task' => 'Eliminar tarea',
	'mark task as completed' => 'Marcar tarea como completada',
	'mark task as open' => 'Marcar tarea como vista',
	'add milestone' => 'Agregar hito',
	'edit milestone' => 'Editar hito',
	'delete milestone' => 'Eliminar hito',
	'add event' => 'Agregar evento',
	'edit event' => 'Editar evento',
	'delete event' => 'Eliminar evento',
	'previous month' => 'Mes anterior',
	'next month' => 'Próximo mes',
	'previous week' => 'Semana anterior',
	'next week' => 'Próxima semana',
	'previous day' => 'Día anterior',
	'next day' => 'Próximo día',
	'back to calendar' => 'Volver al calendario',
	'back to day' => 'Volver al día',
	'pick a date' => 'Elegir fecha',
	'month' => 'Mes',
	'week' => 'Semana',
	'can edit company data' => 'Permitirle editar datos de la empresa propietaria',
	'can manage security' => 'Permitirle modificar configuraciones de seguridad',
	'can manage workspaces' => 'Permitirle modificar configuraciones de espacios',
	'can manage configuration' => 'Permitirle modificar las configuraciones',
	'can manage contacts' => 'Permitirle modificar configuraciones de todos los contactos',
	'group users' => 'Usuarios del grupo',
	'update people' => 'Modificar',
	'remove user from project' => 'Eliminar usuario de este espacio',
	'remove company from project' => 'Eliminar empresa del espacio',
	'update profile' => 'Editar cuenta',
	'change password' => 'Modificar contraseña',
	'update avatar' => 'Guardar nuevo avatar',
	'delete current avatar' => 'Eliminar el avatar actual',
	'add form' => 'Agregar formulario',
	'edit form' => 'Editar formulario',
	'delete form' => 'Eliminar formulario',
	'submit project form' => 'Presentar',
	'add file' => 'Agregar archivo',
	'file properties' => 'Propiedades del archivo',
	'upload file' => 'Cargar archivo',
	'create new revision' => 'Crear nueva revisión',
	'add document' => 'Agregar documento',
	'save document' => 'Guardar documento',
	'add spreadsheet' => 'Agregar hoja de cálculo',
	'add presentation' => 'Agregar presentación',
	'document' => 'Documento',
	'spreadsheet' => 'Hoja de cálculo',
	'presentation' => 'Presentación',
	'new' => 'Nuevo',
	'upload' => 'Cargar',
	'hide' => 'Ocultar',
	'new document' => 'Nuevo Documento',
	'new spreadsheet' => 'Nueva hoja de cálculo',
	'new presentation' => 'Nueva presentación',
	'slideshow' => 'Presentación',
	'revisions and comments' => 'Revisiones y Comentarios',
	'Save' => 'Guardar',
	'all elements' => 'Todos los elementos',
	'collapse all' => 'Colapsar todos',
	'expand all' => 'Expandir todos',
	'properties' => 'Propiedades',
	'edit file' => 'Editar archivo',
	'edit document' => 'Editar documento',
	'edit spreadsheet' => 'Editar hoja de cálculo',
	'edit presentation' => 'Editar presentación',
	'play' => 'Reproducir',
	'queue' => 'Encolar',
	'delete file' => 'Eliminar archivo',
	'add folder' => 'Agregar carpeta',
	'edit folder' => 'Editar carpeta',
	'delete folder' => 'Eliminar carpeta',
	'edit file revisions' => 'Editar revisiones',
	'version' => 'ver',
	'last modification' => 'Última modifiación',
	'link object' => 'Vincular objeto',
	'link objects' => 'Vincular objetos',
	'link more objects' => 'Vincular a más objetos',
	'show all linked objects' => 'Mostrar todos ({0})',
	'unlink' => 'Eliminar vínculo',
	'unlink object' => 'Eliminar vínculo con este objeto',
	'unlink objects' => 'Eliminar vínculo con estos objetos',
	'extract' => 'Extraer',
	'add files to zip' => 'Agregar archivos',
	'delete tag' => 'Eliminar etiqueta',
	'update permissions' => 'Modificar los permisos',
	'edit permissions' => 'Editar permisos',
	'edit permissions explanation' => 'Seleccione los usuarios habilitados para acceder al espacio creado.',
	'save as new revision' => 'Guardar como nueva revisión',
	'save as' => 'Cambiar nombre',
	'details' => 'Detalles',
	'view history for' => 'Ver historial',
	'view history' => 'Ver historial',
	'edit preferences' => 'Editar preferencias',
	'view milestone' => 'Ver hito',
	'custom properties' => 'Propiedades Personalizadas',
	'edit file properties' => 'Editar propiedades del archivo',
	'move to trash' => 'Mover a la papelera',
	'restore from trash' => 'Restaurar desde la papelera',
	'delete permanently' => 'Eliminar permanentemente',
	'archive' => 'Archivar',
	'unarchive' => 'Desarchivar',
	'confirm archive selected objects' => '¿Está seguro que desea archivar los objetos seleccionados?',
	'confirm archive object' => '¿Está seguro que desea archivar este objeto?',
	'confirm unarchive object' => '¿Está seguro que desea desarchivar este objeto?',
	'copy file' => 'Copiar este archivo',
	'open weblink' => 'Abrir enlace web',
	'report as spam' => 'Reportar como Spam',
	'not spam' => 'No es Spam',
	'mark as unread' => 'Marcar como no leído',
	'show' => 'Mostrar',
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/es_la/actions.php <==
<?php return array(
	'register' => 'Registrar',
	'login' => 'Login',
	'logout' => 'Logout',
	'hide welcome info' => '» Ocultar información de forma permanente',
	'add company' => 'Agregar organización',
	'edit company' => 'Editar datos de la organización',
	'delete company' => 'Eliminar organización',
	'edit company logo' => 'Guardar logo',
	'delete company logo' => 'Eliminar logo',
	'add client' => 'Agregar cliente',
	'edit client' => 'Editar cliente',
	'delete client' => 'Eliminar cliente',
	'add user' => 'Agregar usuario',
	'edit user' => 'Editar usuario',
	'delete user' => 'Eliminar usuario',
	'create user from contact' => 'Crear usuario a partir de la persona',
	'add group' => 'Agregar grupo',
	'edit group' => 'Editar grupo',
	'delete group' => 'Eliminar grupo',
	'add project' => 'Agregar espacio',
	'edit project' => 'Editar espacio',
	'delete project' => 'Eliminar espacio',
	'mark project as finished' => 'Marcar espacio como cerrado',
	'mark project as active' => 'Marcar espacio como activo',
	'add workspace' => 'Agregar nuevo espacio',
	'edit workspace' => 'Editar espacio',
	'delete workspace' => 'Eliminar espacio',
	'mark workspace as finished' => 'Marcar espacio como finalizado',
	'mark workspace as active' => 'Marcar espacio como activo',
	'add message' => 'Agregar nota',
	'add new message' => 'Agregar nuevo nota',
	'edit message' => 'Editar nota',
	'delete message' => 'Eliminar nota',
	'view message' => 'Mostrar nota',
	'update message options' => 'Guardar nuevas opciones',
	'subscribe to object' => 'Suscribir',
	'unsubscribe from object' => 'Borrar subscripción',
	'add comment' => 'Agregar comentario',
	'edit comment' => 'Editar comentario',
	'add task list' => 'Agregar tarea',
	'edit task list' => 'Editar tarea',
	'delete task list' => 'Eliminar tarea',
	'reorder tasks' => 'Reordenar tareas',
	'apply milestone to subtasks' => 'Aplicar Hito a Subtareas',
	'apply workspace to subtasks' => 'Aplicar Espacio de Trabajo a Subtareas',
	'reorder sub tasks' => 'Reordenar sub tareas',
	'copy task' => 'Crear copia de esta tarea',
	'copy milestone' => 'Crear copia de este hito',
	'add task' => 'Agregar tarea',
	'add sub task' => 'Agregar subtarea',
	'edit task' => 'Editar tarea',
	'delete task' => 'Eliminar tarea',
	'mark task as completed' => 'Marcar tarea como completada',
	'mark task as open' => 'Marcar tarea como vista',
	'add milestone' => 'Agregar hito',
	'edit milestone' => 'Editar hito',
	'delete milestone' => 'Eliminar hito',
	'add event' => 'Agregar evento',
	'edit event' => 'Editar evento',
	'delete event' => 'Eliminar evento',
	'previous month' => 'Mes anterior',
	'next month' => 'Próximo mes',
	'previous week' => 'Semana anterior',
	'next week' => 'Próxima semana',
	'previous day' => 'Día anterior',
	'next day' => 'Próximo día',
	'back to calendar' => 'Volver al calendario',
	'back to day' => 'Volver al día',
	'pick a date' => 'Elegir fecha',
	'month' => 'Mes',
	'week' => 'Semana',
	'can edit company data' => 'Permitirle editar datos de la organización propietaria',
	'can manage security' => 'Permitirle modificar configuraciones de seguridad',
	'can manage workspaces' => 'Permitirle modificar configuraciones de espacios',
	'can manage configuration' => 'Permitirle modificar las configuraciones',
	'can manage contacts' => 'Permitirle modificar configuraciones de todos las personas',
	'group users' => 'Usuarios del grupo',
	'update people' => 'Modificar',
	'remove user from project' => 'Eliminar usuario de este espacio',
	'remove company from project' => 'Eliminar organización del espacio',
	'update profile' => 'Editar cuenta',
	'change password' => 'Modificar contraseña',
	'update avatar' => 'Guardar nuevo avatar',
	'delete current avatar' => 'Eliminar el avatar actual',
	'add form' => 'Agregar formulario',
	'edit form' => 'Editar formulario',
	'delete form' => 'Eliminar formulario',
	'submit project form' => 'Presentar',
	'add file' => 'Agregar documento',
	'file properties' => 'Propiedades del documento',
	'upload file' => 'Cargar documento',
	'create new revision' => 'Crear nueva revisión',
	'add document' => 'Agregar documento',
	'save document' => 'Guardar documento',
	'add spreadsheet' => 'Agregar hoja de cálculo',
	'add presentation' => 'Agregar presentación',
	'document' => 'Documento',
	'spreadsheet' => 'Hoja de cálculo',
	'presentation' => 'Presentación',
	'new' => 'Nuevo',
	'upload' => 'Cargar',
	'hide' => 'Ocultar',
	'new document' => 'Nuevo Documento',
	'new spreadsheet' => 'Nueva hoja de cálculo',
	'new presentation' => 'Nueva presentación',
	'slideshow' => 'Presentación',
	'revisions and comments' => 'Revisiones y Comentarios',
	'Save' => 'Guardar',
	'all elements' => 'Todos los elementos',
	'collapse all' => 'Colapsar todos',
	'expand all' => 'Expandir todos',
	'properties' => 'Propiedades',
	'edit file' => 'Editar documento',
	'edit document' => 'Editar documento',
	'edit spreadsheet' => 'Editar hoja de cálculo',
	'edit presentation' => 'Editar presentación',
	'play' => 'Reproducir',
	'queue' => 'Encolar',
	'delete file' => 'Eliminar documento',
	'add folder' => 'Agregar carpeta',
	'edit folder' => 'Editar carpeta',
	'delete folder' => 'Eliminar carpeta',
	'edit file revisions' => 'Editar revisiones',
	'version' => 'ver',
	'last modification' => 'Última modifiación',
	'link object' => 'Vincular objeto',
	'link objects' => 'Vincular objetos',
	'link more objects' => 'Vincular a más objetos',
	'show all linked objects' => 'Mostrar todos ({0})',
	'unlink' => 'Eliminar vínculo',
	'unlink object' => 'Eliminar vínculo con este objeto',
	'unlink objects' => 'Eliminar vínculo con estos objetos',
	'extract' => 'Extraer',
	'add files to zip' => 'Agregar documentos',
	'delete tag' => 'Eliminar etiqueta',
	'update permissions' => 'Modificar los permisos',
	'edit permissions' => 'Editar permisos',
	'edit permissions explanation' => 'Seleccione los usuarios habilitados para acceder al espacio creado.',
	'save as new revision' => 'Guardar como nueva revisión',
	'save as' => 'Cambiar nombre',
	'details' => 'Detalles',
	'view history for' => 'Ver historial',
	'view history' => 'Ver historial',
	'edit preferences' => 'Editar preferencias',
	'view milestone' => 'Ver hito',
	'custom properties' => 'Propiedades Personalizadas',
	'edit file properties' => 'Editar propiedades del documento',
	'move to trash' => 'Mover a la papelera',
	'restore from trash' => 'Restaurar desde la papelera',
	'delete permanently' => 'Eliminar permanentemente',
	'archive' => 'Archivar',
	'unarchive' => 'Desarchivar',
	'confirm archive selected objects' => '¿Está seguro que desea archivar los objetos seleccionados?',
	'confirm archive object' => '¿Está seguro que desea archivar este objeto?',
	'confirm unarchive object' => '¿Está seguro que desea desarchivar este objeto?',
	'copy file' => 'Copiar este documento',
	'open weblink' => 'Abrir enlace web',
	'report as spam' => 'Reportar como Spam',
	'not spam' => 'No es Spam',
	'mark as unread' => 'Marcar como no leído',
	'show' => 'Mostrar',
	'activate' => 'Activar',
	'disabled' => 'Desactivado',
	'template context' => 'Eliga la ubicación de la plantilla',
); ?>
